# Simple Repository

## Install

```
$ npm i @banxware/simple-repository
```

## Usage

### Dynamo Repository

```ts
type User {
  id: string
  firstName: string
  lastName: string
  active: boolean
}

class UserRepository extends SimpleDynamoRepository<User> {
  async findActiveUsersByName(name: string): Promise<BankConnection> {
    return await this.findByQuery({
      IndexName: 'name',
      KeyConditionExpression: 'name = :name AND active = :active',
      ExpressionAttributeValues: {
        ':name': name,
        ':active': true,
      },
    })
  }
}

const userRepository = new UserRepository(new DynamoDBClient({ region: 'eu-central-1' }), 'users')

userRepository.save({ id: 'uuid', firstName: 'john', lastName: 'doe', active: true })
userRepository.save({ id: 'uuid2', firstName: 'john', lastName: 'travolta', active: false })
userRepository.findOne('uuid')
userRepository.findActiveUsersByName('john')
userRepository.findAll()
```

